/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef CHARTWINDOW_H
#define CHARTWINDOW_H

#include <QWidget>
#include <QScopedPointer>
#include <QList>
#include <QPointer>
#include <QDateTime>

#include "chartoptionsdialog.h"
#include "qcp/qcustomplot.h"
#include "basicqcpinteractionmanager.h"

#include "sampleset.h"

namespace Ui {
class ChartWindow;
}

class ChartWindow : public QWidget
{
    Q_OBJECT
    
public:
    explicit ChartWindow(SampleSet samples, SampleColumns columns,
                         QWidget *parent = 0);
    ~ChartWindow();
    
private slots:
    // chart slots
    void axisDoubleClick(QCPAxis*axis,
                         QCPAxis::SelectablePart part,
                         QMouseEvent* event);
    void titleDoubleClick(QMouseEvent*event, QCPPlotTitle*title);



    // Context menu related stuff
    void chartContextMenuRequested(QPoint point);
    void addTitle();
    void removeTitle();
    void showLegendToggle();
    void showTitleToggle();
    void showGridToggle();
    void moveLegend();
    void toggleYAxisLock();

    // Save As slot
    void save();

private:
    void showLegendContextMenu(QPoint point);

    QList<QCPAxis*> valueAxes();

    bool gridVisible;


    Ui::ChartWindow *ui;

    QPointer<QCPPlotTitle> plotTitle;
    QString plotTitleValue;

    QScopedPointer<BasicQCPInteractionManager> basicInteractionManager;
};

#endif // CHARTWINDOW_H
