/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QObject>
#include <QSettings>
#include <QColor>

typedef struct _chart_colours {
    QColor temperature;
    QColor humidity;
    QColor dewPoint;
} ChartColours;

typedef struct _chart_graphs {
    bool temperature;
    bool humidity;
    bool dewPoint;
} ChartGraphs;

class Settings : public QObject
{
    Q_OBJECT
public:
    static Settings& getInstance() {
        static Settings instance;
        return instance;
    }

    enum data_source_type_t {DS_TYPE_DATABASE, DS_TYPE_TEMPER, DS_TYPE_TEMPERHUM};

    /* General Settings */
    void setMinimiseToSysTray(bool enabled);
    bool miniseToSysTray();

    void setCloseToSysTray(bool enabled);
    bool closeToSysTray();

    void setChartColours(ChartColours colours);
    ChartColours getChartColours();

    void setMainWindowGraphsEnabled(ChartGraphs graphs);
    ChartGraphs getMainWindowGraphsEnabled();

    void setMainWindowGraphLegendEnabled(bool enabled);
    bool mainWindowGraphLegendEnabled();

    void setMainWindowGraphAveraged(bool enabled);
    bool mainWindowGraphAveraged();

    bool logToDatabase();
    void setLogToDatabase(bool enabled);

    bool promptOnExitIfLogging();

    /* Data Source */
    void setLiveDataSourceType(Settings::data_source_type_t type);
    Settings::data_source_type_t liveDataSourceType();

    void setTemperatureCalibrationOffset(float value);
    float temperatureCalibrationOffset();

    void setHumidityCalibrationOffset(float value);
    float humidityCalibrationOffset();

    void setStationCode(QString code);
    QString stationCode();

    void setUseIndoorSensors(bool enabled);
    bool useIndoorSensors();

    /* Database settings */
    void setDatabaseDriver(QString driver);
    QString databaseDriver();

    void setDatabaseFileName(QString filename);
    QString databaseFileName();

    void setDatabaseName(QString dbName);
    QString databaseName();

    void setDatabaseHostname(QString hostName);
    QString databaseHostName();

    void setDatabasePort(int port);
    int databasePort();

    void setDatabaseUsername(QString username);
    QString databaseUsername();

    void setDatabasePassword(QString password);
    QString databasePassword();


    /* Single shot stuff */
    void setSingleShotMinimiseToSysTray();
    bool singleShotMinimiseToSysTray();

    void setSingleShotCloseToSysTray();
    bool singleShotCloseToSysTray();

    bool isFirstRun();

private:
    explicit Settings();
    ~Settings();

    Settings(Settings const&); /* Not implemented. Don't use it. */
    void operator=(Settings const&); /* Not implemented. Don't use it. */

    QSettings *settings;
};

#endif // SETTINGS_H
