/*****************************************************************************
 *          Copyright: (C) Copyright David Goodwin, 2014
 *            License: GNU General Public License
 *****************************************************************************
 *
 *   This is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This software is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this software; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ****************************************************************************/

#ifndef TEMPERDATASOURCE_H
#define TEMPERDATASOURCE_H

#include "abstractdatasource.h"

#include <hidapi.h>
#include <QTimer>
#include <QScopedPointer>

class TemperDataSource : public AbstractDataSource
{
    Q_OBJECT
public:
    explicit TemperDataSource(float calibrationOffset = 0.0, QObject *parent = 0);
    ~TemperDataSource();

    virtual bool openDevice();
    virtual bool closeDevice();

    void setInterval(int interval);
    int getInterval() const;

    virtual void startCollecting();
    virtual void stopCollecting();
    virtual bool isCollecting();

protected slots:
    virtual void collectData();

private:
    hid_device *handle;
    QScopedPointer<QTimer> timer;

    double getCalibrationValue() const;
    QString getVersion() const;
    float getTemperature() const;
    float calibrationOffset;
    bool collecting;
};

#endif // TEMPERDATASOURCE_H
